[![npm](https://img.shields.io/npm/v/aggregate-async-iterator.svg)](https://www.npmjs.com/package/aggregate-async-iterator)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![minified size](https://badgen.net/bundlephobia/min/aggregate-async-iterator)](https://bundlephobia.com/result?p=aggregate-async-iterator)
[![downloads](http://img.shields.io/npm/dm/aggregate-async-iterator.svg?style=flat-square)](https://npmjs.org/package/aggregate-async-iterator)
[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/arlac77/aggregate-async-iterator.git)
[![Styled with prettier](https://img.shields.io/badge/styled_with-prettier-ff69b4.svg)](https://github.com/prettier/prettier)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/)

# aggregate-async-iterator

Aggregates several async iterators into one

# usage

```js
import { aggregateRoundRobin } from "aggregate-async-iterator";

async function* sequence(name, time = 100, num = 10) {
  for (let i = 0; i < num; i += 1) {
    yield new Promise(resolve => setTimeout(resolve(name + i), time));
  }
}

for await (const r of aggregateRoundRobin([
    sequence("A", 100, 5),
    sequence("B", 50, 7)
  ])) {
  console.log(r);
}
```

Prints interleved sequences

```txt
A0
B0
A1
B1
A2
B2
A3
B3
A4
B4
B5
B6
```

# API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [aggregateFifo](#aggregatefifo)
    -   [Parameters](#parameters)
-   [aggregateRoundRobin](#aggregateroundrobin)
    -   [Parameters](#parameters-1)

## aggregateFifo

Aggregate items from sevaral iterators into one.
Items are collected first in first out from the sources.
Whatever source comes first will be delivered first.

### Parameters

-   `sources` **[Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;AsyncItarator&lt;any>>** 

Returns **AsyncItarator&lt;any>** items collected from all sources

## aggregateRoundRobin

Aggregate items from sevaral iterators into one.
Items are collected round robin from the sources.

### Parameters

-   `sources` **[Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;AsyncItarator&lt;any>>** 

Returns **AsyncItarator&lt;any>** items collected from all sources

# install

With [npm](http://npmjs.org) do:

```shell
npm install aggregate-async-iterator
```

# license

BSD-2-Clause
